# Colors

Colors can be defined in several places: background of boxes, color of text, and path drawing. All these places uses the color format:

* Color keyword: e.g. `"green"`, `"blue"`. See list of [recognized SVG color names](https://upload.wikimedia.org/wikipedia/commons/2/2b/SVG_Recognized_color_keyword_names.svg)
* Hex color value: e.g. `"#fff"`, `"#a0a0a0"`.
* RGB values: e.g. `"rgb(34, 12, 64, 0.6)"`.
* HSL values: e.g. `"hsl(30, 100%, 50%, 0.6)"`.
